pub trait ConfigurationExt {
// Required methods
fn set_bind(
&mut self,
addr: IpAddr,
port_range_start: u16,
port_range_end: u16,
);
fn set_enable_ice_udp_mux(&mut self, value: bool);
}Expand description
Native platform-specific extensions to crate::Configuration.
Required Methods
Sourcefn set_bind(&mut self, addr: IpAddr, port_range_start: u16, port_range_end: u16)
fn set_bind(&mut self, addr: IpAddr, port_range_start: u16, port_range_end: u16)
Set an address and port range to bind to.
Sourcefn set_enable_ice_udp_mux(&mut self, value: bool)
fn set_enable_ice_udp_mux(&mut self, value: bool)
If true, connections are multiplexed on the same UDP port.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".